import os
import unittest

from checkov.terraform.context_parsers.registry import parser_registry
from tests.terraform.context_parsers.mock_context_parser import MockContextParser

mock_tf_file = os.path.dirname(os.path.realpath(__file__)) + '/mock_tf_files/mock.tf'
mock_definition = (mock_tf_file, {'mock': [
    {
        'mock_type': {
            'mock_name': {
                'value': [
                    'mock_value']}}}
]})


class TestBaseParser(unittest.TestCase):

    def test_enrich_definition_block(self):
        mock_parser = MockContextParser()
        parser_registry.register(mock_parser)
        definition_context = parser_registry.enrich_definitions_context(mock_definition)
        skipped_checks = definition_context[mock_tf_file]['mock']['mock_type']['mock_name'].get('skipped_checks')
        self.assertIsNotNone(skipped_checks)
        self.assertEqual(len(skipped_checks), 3)
        # Ensure checkov IDs are mapped to BC IDs
        self.assertEqual(skipped_checks[2]['id'], 'CKV_AWS_15')


if __name__ == '__main__':
    unittest.main()
